@@ -50,8 +50,6 @@
 #include <XdgIcon>
 
 // statically linked built-in plugins
-#include "../plugin-clock/lxqtclock.h" // clock
-extern void * loadPluginTranslation_clock_helper;
 #include "../plugin-desktopswitch/desktopswitch.h" // desktopswitch
 extern void * loadPluginTranslation_desktopswitch_helper;
 #include "../plugin-mainmenu/lxqtmainmenu.h" // mainmenu
@@ -194,9 +192,6 @@ namespace
     //NOTE2: we need to reference some (dummy) symbol from (autogenerated) LXQtPluginTranslationLoader.cpp
     // to be not stripped (as unused/unreferenced) in static linking time
     static plugin_tuple_t const static_plugins[] = {
-#if defined(WITH_CLOCK_PLUGIN)
-        std::make_tuple(QLatin1String("clock"), plugin_ptr_t{new LXQtClockPluginLibrary}, loadPluginTranslation_clock_helper),// clock
-#endif
 #if defined(WITH_DESKTOPSWITCH_PLUGIN)
         std::make_tuple(QLatin1String("desktopswitch"), plugin_ptr_t{new DesktopSwitchPluginLibrary}, loadPluginTranslation_desktopswitch_helper),// desktopswitch
 #endif
