@@ -2,15 +2,15 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="ja">
 <context>
-    <name>LxQtCpuLoad</name>
+    <name>LXQtCpuLoad</name>
     <message>
-        <location filename="../lxqtcpuload.cpp" line="119"/>
+        <location filename="../lxqtcpuload.cpp" line="127"/>
         <source>CPU load %1%</source>
         <translation>CPU負荷 %1%</translation>
     </message>
 </context>
 <context>
-    <name>LxQtCpuLoadConfiguration</name>
+    <name>LXQtCpuLoadConfiguration</name>
     <message>
         <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
         <source>CPU Load Settings</source>
@@ -41,6 +41,11 @@
         <source>Bar orientation:</source>
         <translation>バーの向き:</translation>
     </message>
+    <message>
+        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
+        <source>Bar width:</source>
+        <translation>バーの幅:</translation>
+    </message>
     <message>
         <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
         <source>Bottom up</source>
