@@ -30,6 +30,8 @@
 #include "directorymenu.h"
 #include <QDebug>
 #include <QDesktopServices>
+#include <QProcess>
+#include <QStringList>
 #include <QFileInfo>
 #include <QUrl>
 #include <QIcon>
@@ -43,6 +45,7 @@ DirectoryMenu::DirectoryMenu(const ILXQtPanelPluginStartupInfo &startupInfo) :
     mDefaultIcon(XdgIcon::fromTheme("folder"))
 {
     mOpenDirectorySignalMapper = new QSignalMapper(this);
+    mOpenTerminalSignalMapper = new QSignalMapper(this);
     mMenuSignalMapper = new QSignalMapper(this);
 
     mButton.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
@@ -51,6 +54,7 @@ DirectoryMenu::DirectoryMenu(const ILXQtPanelPluginStartupInfo &startupInfo) :
 
     connect(&mButton, SIGNAL(clicked()), this, SLOT(showMenu()));
     connect(mOpenDirectorySignalMapper, SIGNAL(mapped(QString)), this, SLOT(openDirectory(QString)));
+    connect(mOpenTerminalSignalMapper, SIGNAL(mapped(QString)), this, SLOT(openInTerminal(QString)));
     connect(mMenuSignalMapper, SIGNAL(mapped(QString)), this, SLOT(addMenu(QString)));
 
     settingsChanged();
@@ -102,6 +106,15 @@ void DirectoryMenu::openDirectory(const QString& path)
     QDesktopServices::openUrl(QUrl("file://" + QDir::toNativeSeparators(path)));
 }
 
+void DirectoryMenu::openInTerminal(const QString& path)
+{
+    // Create list of arguments
+    QStringList args;
+    args << "--workdir" << QDir::toNativeSeparators(path);
+    // Execute the default terminal program with arguments
+    QProcess::startDetached(mDefaultTerminal, args);
+}
+
 void DirectoryMenu::addMenu(QString path)
 {
     QSignalMapper* sender = (QSignalMapper* )QObject::sender();
@@ -121,6 +134,10 @@ void DirectoryMenu::addActions(QMenu* menu, const QString& path)
     connect(openDirectoryAction, SIGNAL(triggered()), mOpenDirectorySignalMapper, SLOT(map()));
     mOpenDirectorySignalMapper->setMapping(openDirectoryAction, mPathStrings.back());
 
+    QAction* openTerminalAction = menu->addAction(XdgIcon::fromTheme("folder"), tr("Open in terminal"));
+    connect(openTerminalAction, SIGNAL(triggered()), mOpenTerminalSignalMapper, SLOT(map()));
+    mOpenTerminalSignalMapper->setMapping(openTerminalAction, mPathStrings.back());
+
     menu->addSeparator();
 
     QDir dir(path);
@@ -163,4 +180,7 @@ void DirectoryMenu::settingsChanged()
     }
 
     mButton.setIcon(mDefaultIcon);
+
+    // Set default terminal
+    mDefaultTerminal = settings()->value("defaultTerminal", QString()).toString();
 }
