@@ -2,37 +2,25 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="sr_BA">
 <context>
-    <name>LxQtMainMenu</name>
+    <name>LXQtMainMenu</name>
     <message>
-        <location filename="../lxqtmainmenu.cpp" line="314"/>
-        <source>Show/hide main menu</source>
+        <location filename="../lxqtmainmenu.cpp" line="98"/>
+        <source>Search...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenu.cpp" line="339"/>
-        <source>Leave</source>
-        <translation>Напуштање</translation>
+        <location filename="../lxqtmainmenu.cpp" line="104"/>
+        <source>Show/hide main menu</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>LxQtMainMenuConfiguration</name>
-    <message>
-        <source>LxQt Main Menu settings</source>
-        <translation type="vanished">Подешавања главног менија</translation>
-    </message>
+    <name>LXQtMainMenuConfiguration</name>
     <message>
         <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
         <source>General</source>
         <translation>Опште</translation>
     </message>
-    <message>
-        <source>Show text</source>
-        <translation type="vanished">Прикажи текст</translation>
-    </message>
-    <message>
-        <source>Button text</source>
-        <translation type="vanished">Текст тастера</translation>
-    </message>
     <message>
         <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
         <source>Main Menu settings</source>
@@ -40,56 +28,106 @@
     </message>
     <message>
         <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
+        <source>Icon:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
         <source>Button text:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="52"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
         <source>Custom font size:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="62"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
         <source> pt</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="81"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
         <source>Menu file</source>
         <translation>Фајл менија</translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="87"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
         <source>Menu file:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="101"/>
-        <source>...</source>
-        <translation>...</translation>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
+        <source>Max. item width:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
+        <source>Show matching entries:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
+        <source>Maximum visible items:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
+        <source>Filter menu entries</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
+        <source> px</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
+        <source>Hide menu entries while searching</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
+        <source>Clear search upon showing menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
         <source>Keyboard Shortcut</source>
         <translation>Пречица тастатуре</translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.ui" line="130"/>
+        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
         <source>Click the button to record shortcut:</source>
         <translation>Кликните на тастер да снимите пречицу:</translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.cpp" line="55"/>
+        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
         <source>Reset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
+        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
+        <source>Choose icon file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
+        <source>Images (*.svg *.png)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
         <source>Choose menu file</source>
         <translation>Изабери фајл менија</translation>
     </message>
     <message>
-        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
+        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
         <source>Menu files (*.menu)</source>
         <translation>Фајлови менија (*.menu)</translation>
     </message>
