@@ -2,95 +2,87 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="es_UY">
 <context>
-    <name>DeviceActionInfo</name>
+    <name>Button</name>
     <message>
-        <location filename="../actions/deviceaction_info.cpp" line="45"/>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
-        <translation type="unfinished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está conectado.</translation>
-    </message>
-    <message>
-        <location filename="../actions/deviceaction_info.cpp" line="53"/>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
-        <translation type="unfinished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; fue quitado.</translation>
-    </message>
-    <message>
-        <location filename="../actions/deviceaction_info.cpp" line="59"/>
+        <location filename="../button.cpp" line="38"/>
         <source>Removable media/devices manager</source>
         <translation type="unfinished">Administrador de dispositivos desmontables</translation>
     </message>
 </context>
 <context>
-    <name>LxQtMountConfiguration</name>
+    <name>Configuration</name>
     <message>
-        <source>LxQt Removable media manager settings</source>
-        <translation type="vanished">Configuración de dispositivos desmontables LxQt</translation>
-    </message>
-    <message>
-        <location filename="../lxqtmountconfiguration.ui" line="14"/>
+        <location filename="../configuration.ui" line="14"/>
         <source>Removable Media Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.ui" line="20"/>
+        <location filename="../configuration.ui" line="20"/>
         <source>Behaviour</source>
-        <translation>Comportamiento</translation>
+        <translation type="unfinished">Comportamiento</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.ui" line="26"/>
-        <source>When a device is connected </source>
-        <translation>Cuando un dispositivo es conectado</translation>
+        <location filename="../configuration.ui" line="26"/>
+        <source>When a device is connected:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="44"/>
+        <location filename="../configuration.cpp" line="40"/>
         <source>Popup menu</source>
-        <translation>Menú emergente</translation>
+        <translation type="unfinished">Menú emergente</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="45"/>
+        <location filename="../configuration.cpp" line="41"/>
         <source>Show info</source>
-        <translation>Mostrar información</translation>
+        <translation type="unfinished">Mostrar información</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="46"/>
+        <location filename="../configuration.cpp" line="42"/>
         <source>Do nothing</source>
-        <translation>No hacer nada</translation>
+        <translation type="unfinished">No hacer nada</translation>
+    </message>
+</context>
+<context>
+    <name>DeviceActionInfo</name>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="40"/>
+        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
+        <translation type="unfinished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está conectado.</translation>
+    </message>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="45"/>
+        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
+        <translation type="unfinished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; fue quitado.</translation>
+    </message>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="50"/>
+        <source>Removable media/devices manager</source>
+        <translation type="unfinished">Administrador de dispositivos desmontables</translation>
     </message>
 </context>
 <context>
     <name>MenuDiskItem</name>
     <message>
-        <source>Click to access this device from other applications.</source>
-        <translation type="vanished">Presione para acceder a este dispositivo desde otras aplicaciones.</translation>
+        <location filename="../menudiskitem.cpp" line="155"/>
+        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Click to eject this disc.</source>
-        <translation type="vanished">Presione para expulsar este disco.</translation>
-    </message>
-</context>
-<context>
-    <name>MountButton</name>
-    <message>
-        <location filename="../mountbutton.cpp" line="39"/>
+        <location filename="../menudiskitem.cpp" line="157"/>
+        <location filename="../menudiskitem.cpp" line="178"/>
         <source>Removable media/devices manager</source>
-        <translation>Administrador de dispositivos desmontables</translation>
+        <translation type="unfinished">Administrador de dispositivos desmontables</translation>
     </message>
     <message>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
-        <translation type="vanished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está conectado.</translation>
-    </message>
-    <message>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
-        <translation type="vanished">El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; fue quitado.</translation>
-    </message>
-    <message>
-        <source>No devices Available.</source>
-        <translation type="vanished">No hay dispositivos disponibles.</translation>
+        <location filename="../menudiskitem.cpp" line="176"/>
+        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Popup</name>
     <message>
-        <location filename="../popup.cpp" line="56"/>
+        <location filename="../popup.cpp" line="68"/>
         <source>No devices are available</source>
         <translation type="unfinished"></translation>
     </message>
