@@ -24,7 +24,7 @@
     <message>
         <location filename="../configuration.ui" line="26"/>
         <source>When a device is connected:</source>
-        <translation type="unfinished"></translation>
+        <translation>Quando un device è connesso:</translation>
     </message>
     <message>
         <location filename="../configuration.cpp" line="40"/>
