@@ -2,95 +2,87 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="sl">
 <context>
-    <name>DeviceActionInfo</name>
+    <name>Button</name>
     <message>
-        <location filename="../actions/deviceaction_info.cpp" line="45"/>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
-        <translation type="unfinished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je priključena.</translation>
-    </message>
-    <message>
-        <location filename="../actions/deviceaction_info.cpp" line="53"/>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
-        <translation type="unfinished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je odstranjena.</translation>
-    </message>
-    <message>
-        <location filename="../actions/deviceaction_info.cpp" line="59"/>
+        <location filename="../button.cpp" line="38"/>
         <source>Removable media/devices manager</source>
         <translation type="unfinished">Upravljalnik odstranljivih nosilcev/naprav</translation>
     </message>
 </context>
 <context>
-    <name>LxQtMountConfiguration</name>
+    <name>Configuration</name>
     <message>
-        <source>LxQt Removable media manager settings</source>
-        <translation type="vanished">Nastavitve upravljalnika odstranljivih nosilcev</translation>
-    </message>
-    <message>
-        <location filename="../lxqtmountconfiguration.ui" line="14"/>
+        <location filename="../configuration.ui" line="14"/>
         <source>Removable Media Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.ui" line="20"/>
+        <location filename="../configuration.ui" line="20"/>
         <source>Behaviour</source>
-        <translation>Obnašanje</translation>
+        <translation type="unfinished">Obnašanje</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.ui" line="26"/>
-        <source>When a device is connected </source>
-        <translation>Ko se naprava priključi </translation>
+        <location filename="../configuration.ui" line="26"/>
+        <source>When a device is connected:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="44"/>
+        <location filename="../configuration.cpp" line="40"/>
         <source>Popup menu</source>
-        <translation>Prikaži meni</translation>
+        <translation type="unfinished">Prikaži meni</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="45"/>
+        <location filename="../configuration.cpp" line="41"/>
         <source>Show info</source>
-        <translation>Prikaži podatke</translation>
+        <translation type="unfinished">Prikaži podatke</translation>
     </message>
     <message>
-        <location filename="../lxqtmountconfiguration.cpp" line="46"/>
+        <location filename="../configuration.cpp" line="42"/>
         <source>Do nothing</source>
-        <translation>Ne naredi nič</translation>
+        <translation type="unfinished">Ne naredi nič</translation>
+    </message>
+</context>
+<context>
+    <name>DeviceActionInfo</name>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="40"/>
+        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
+        <translation type="unfinished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je priključena.</translation>
+    </message>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="45"/>
+        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
+        <translation type="unfinished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je odstranjena.</translation>
+    </message>
+    <message>
+        <location filename="../actions/deviceaction_info.cpp" line="50"/>
+        <source>Removable media/devices manager</source>
+        <translation type="unfinished">Upravljalnik odstranljivih nosilcev/naprav</translation>
     </message>
 </context>
 <context>
     <name>MenuDiskItem</name>
     <message>
-        <source>Click to access this device from other applications.</source>
-        <translation type="vanished">Kliknite, da omogočite dostop do naprave iz programov.</translation>
+        <location filename="../menudiskitem.cpp" line="155"/>
+        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Click to eject this disc.</source>
-        <translation type="vanished">Kliknite za izmet diska.</translation>
-    </message>
-</context>
-<context>
-    <name>MountButton</name>
-    <message>
-        <location filename="../mountbutton.cpp" line="39"/>
+        <location filename="../menudiskitem.cpp" line="157"/>
+        <location filename="../menudiskitem.cpp" line="178"/>
         <source>Removable media/devices manager</source>
-        <translation>Upravljalnik odstranljivih nosilcev/naprav</translation>
+        <translation type="unfinished">Upravljalnik odstranljivih nosilcev/naprav</translation>
     </message>
     <message>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
-        <translation type="vanished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je priključena.</translation>
-    </message>
-    <message>
-        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
-        <translation type="vanished">Naprava &lt;b&gt;&lt;nobr&gt;%1&lt;/nobr&gt;&lt;/b&gt; je odstranjena.</translation>
-    </message>
-    <message>
-        <source>No devices Available.</source>
-        <translation type="vanished">Na voljo ni nobene naprave</translation>
+        <location filename="../menudiskitem.cpp" line="176"/>
+        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Popup</name>
     <message>
-        <location filename="../popup.cpp" line="56"/>
+        <location filename="../popup.cpp" line="68"/>
         <source>No devices are available</source>
         <translation type="unfinished"></translation>
     </message>
