@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="ja">
 <context>
-    <name>LxQtNetworkMonitor</name>
+    <name>LXQtNetworkMonitor</name>
     <message>
         <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
         <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
@@ -50,7 +50,7 @@
     </message>
 </context>
 <context>
-    <name>LxQtNetworkMonitorConfiguration</name>
+    <name>LXQtNetworkMonitorConfiguration</name>
     <message>
         <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
         <source>Network Monitor settings</source>
