@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
 <context>
-    <name>LxQtNetworkMonitor</name>
+    <name>LXQtNetworkMonitor</name>
     <message>
         <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
         <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
@@ -50,15 +50,11 @@
     </message>
 </context>
 <context>
-    <name>LxQtNetworkMonitorConfiguration</name>
-    <message>
-        <source>LxQt Network Monitor settings</source>
-        <translation type="vanished">LxQt網路監視器設定</translation>
-    </message>
+    <name>LXQtNetworkMonitorConfiguration</name>
     <message>
         <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
         <source>Network Monitor settings</source>
-        <translation type="unfinished"></translation>
+        <translation>網路顯示器設定</translation>
     </message>
     <message>
         <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
