@@ -2,40 +2,41 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="cs">
 <context>
-    <name>LxQtQuickLaunch</name>
+    <name>LXQtQuickLaunch</name>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
-        <translation>Problém s upuštěním</translation>
+        <translation>Problém s upuštěním sem</translation>
     </message>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="215"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>Soubor/URL &apos;%1&apos; nyní nelze vložit do rychlého spuštění</translation>
+        <translation>Soubor/URL „%1“ nyní nelze vložit do rychlého spuštění</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="319"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Sem přetáhněte
+ikonu aplikace</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
-        <translation>Přesunout vlevo</translation>
+        <translation>Posunout vlevo</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
-        <translation>Přesunout vpravo</translation>
+        <translation>Posunout vpravo</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
-        <translation>Odstranit z rychlého spuštění</translation>
+        <translation>Odebrat z rychlého spuštění</translation>
     </message>
 </context>
 </TS>
