@@ -4,38 +4,38 @@
 <context>
     <name>LXQtQuickLaunch</name>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="219"/>
+        <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
-        <translation type="unfinished">Slipfejl</translation>
+        <translation>Fejl ved slip</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="220"/>
+        <location filename="../lxqtquicklaunch.cpp" line="215"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>Fil/URL &apos;%1&apos; kan ikke indlejres i HurtigStart lige nu</translation>
+        <translation>Filen/URL&apos;en &apos;%1&apos; kan ikke indlejres i hurtigstart på nuværende tidspunkt</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="327"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Slip programikoner her</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="52"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
         <translation>Flyt mod venstre</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="55"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
         <translation>Flyt mod højre</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="59"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
-        <translation>Fjern fra Hurtigstart</translation>
+        <translation>Fjern fra hurtigstart</translation>
     </message>
 </context>
 </TS>
