@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="es_VE">
 <context>
-    <name>LxQtQuickLaunch</name>
+    <name>LXQtQuickLaunch</name>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
@@ -14,7 +14,7 @@
         <translation>Archivo/URL &apos;%1&apos; no puede ser empotrado en la barra de lanzadores por ahora</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="319"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
         <translation type="unfinished"></translation>
@@ -23,17 +23,17 @@ icons here</source>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
         <translation>Mover a la izquierda</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
         <translation>Mover a la derecha</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
         <translation>Remover de la barra de lanzadores</translation>
     </message>
