@@ -2,40 +2,41 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="pt">
 <context>
-    <name>LxQtQuickLaunch</name>
+    <name>LXQtQuickLaunch</name>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
-        <translation>Erro ao largar</translation>
+        <translation>Erro ao soltar</translation>
     </message>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="215"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>Neste momento, não pode incluir o ficheiro/url &apos;%1&apos; no inicio rápido.</translation>
+        <translation>Ficheiro/URL &apos;%1&apos; ainda não pode ser incorporado no Início rápido</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="319"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Largue aqui os
+ícones da aplicação</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
-        <translation>Mover para a esquerda</translation>
+        <translation>Mover para esquerda</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
-        <translation>Mover para a direita</translation>
+        <translation>Mover para direita</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
-        <translation>Remover do inicio rápido</translation>
+        <translation>Remover de Início rápido</translation>
     </message>
 </context>
 </TS>
