@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
 <context>
-    <name>LxQtQuickLaunch</name>
+    <name>LXQtQuickLaunch</name>
     <message>
         <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
@@ -14,26 +14,27 @@
         <translation>檔案位址&apos;%1&apos;現在無法嵌入至快速啟動</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="319"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>在此放置
+應用程式圖示</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="53"/>
+        <location filename="../quicklaunchbutton.cpp" line="55"/>
         <source>Move left</source>
         <translation>往左移</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="56"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
         <source>Move right</source>
         <translation>往右移</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="60"/>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
         <translation>從快速啟動中移除</translation>
     </message>
