@@ -4,19 +4,19 @@
 <context>
     <name>ShowDesktop</name>
     <message>
-        <location filename="../showdesktop.cpp" line="48"/>
+        <location filename="../showdesktop.cpp" line="44"/>
         <source>Show desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Asztalmegjelenítés</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="58"/>
+        <location filename="../showdesktop.cpp" line="66"/>
         <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
-        <translation type="unfinished"></translation>
+        <translation>Asztalmegjelenítés: A &apos;%1&apos; gyorsbillentyű nem regisztrálható</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="63"/>
+        <location filename="../showdesktop.cpp" line="51"/>
         <source>Show Desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Asztalmegjelenítés</translation>
     </message>
 </context>
 </TS>
