@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2012 Razor team
  * Authors:
@@ -37,13 +37,14 @@
 #include <QPainter>
 #include <QResizeEvent>
 #include <QVBoxLayout>
+#include <QCoreApplication>
 
-LxQtSysStat::LxQtSysStat(const ILxQtPanelPluginStartupInfo &startupInfo):
+LXQtSysStat::LXQtSysStat(const ILXQtPanelPluginStartupInfo &startupInfo):
     QObject(),
-    ILxQtPanelPlugin(startupInfo),
+    ILXQtPanelPlugin(startupInfo),
     mWidget(new QWidget()),
-    mFakeTitle(new LxQtSysStatTitle(mWidget)),
-    mContent(new LxQtSysStatContent(this, mWidget))
+    mFakeTitle(new LXQtSysStatTitle(mWidget)),
+    mContent(new LXQtSysStatContent(this, mWidget))
 {
     QVBoxLayout *borderLayout = new QVBoxLayout(mWidget);
     borderLayout->setContentsMargins(0, 0, 0, 0);
@@ -60,24 +61,24 @@ LxQtSysStat::LxQtSysStat(const ILxQtPanelPluginStartupInfo &startupInfo):
     QTimer::singleShot(0, this, SLOT(lateInit()));
 }
 
-LxQtSysStat::~LxQtSysStat()
+LXQtSysStat::~LXQtSysStat()
 {
     delete mWidget;
 }
 
-void LxQtSysStat::lateInit()
+void LXQtSysStat::lateInit()
 {
     settingsChanged();
     mContent->setTitleFont(mFakeTitle->font());
     mSize = mContent->size();
 }
 
-QDialog *LxQtSysStat::configureDialog()
+QDialog *LXQtSysStat::configureDialog()
 {
-    return new LxQtSysStatConfiguration(settings(), mWidget);
+    return new LXQtSysStatConfiguration(settings(), mWidget);
 }
 
-void LxQtSysStat::realign()
+void LXQtSysStat::realign()
 {
     QSize newSize = mContent->size();
     if (mSize != newSize)
@@ -87,23 +88,23 @@ void LxQtSysStat::realign()
     }
 }
 
-void LxQtSysStat::settingsChanged()
+void LXQtSysStat::settingsChanged()
 {
     mContent->updateSettings(settings());
 }
 
-LxQtSysStatTitle::LxQtSysStatTitle(QWidget *parent):
+LXQtSysStatTitle::LXQtSysStatTitle(QWidget *parent):
     QLabel(parent)
 {
 
 }
 
-LxQtSysStatTitle::~LxQtSysStatTitle()
+LXQtSysStatTitle::~LXQtSysStatTitle()
 {
 
 }
 
-bool LxQtSysStatTitle::event(QEvent *e)
+bool LXQtSysStatTitle::event(QEvent *e)
 {
     if (e->type() == QEvent::FontChange)
         emit fontChanged(font());
@@ -111,7 +112,7 @@ bool LxQtSysStatTitle::event(QEvent *e)
     return QLabel::event(e);
 }
 
-LxQtSysStatContent::LxQtSysStatContent(ILxQtPanelPlugin *plugin, QWidget *parent):
+LXQtSysStatContent::LXQtSysStatContent(ILXQtPanelPlugin *plugin, QWidget *parent):
     QWidget(parent),
     mPlugin(plugin),
     mStat(NULL),
@@ -124,7 +125,7 @@ LxQtSysStatContent::LxQtSysStatContent(ILxQtPanelPlugin *plugin, QWidget *parent
     setObjectName("SysStat_Graph");
 }
 
-LxQtSysStatContent::~LxQtSysStatContent()
+LXQtSysStatContent::~LXQtSysStatContent()
 {
 }
 
@@ -133,7 +134,7 @@ LxQtSysStatContent::~LxQtSysStatContent()
 
 #undef QSS_GET_COLOUR
 #define QSS_GET_COLOUR(GETNAME) \
-QColor LxQtSysStatContent::GETNAME##Colour() const \
+QColor LXQtSysStatContent::GETNAME##Colour() const \
 { \
     return mThemeColours.GETNAME##Colour; \
 }
@@ -141,7 +142,7 @@ QColor LxQtSysStatContent::GETNAME##Colour() const \
 #undef QSS_COLOUR
 #define QSS_COLOUR(GETNAME, SETNAME) \
 QSS_GET_COLOUR(GETNAME) \
-void LxQtSysStatContent::SETNAME##Colour(QColor value) \
+void LXQtSysStatContent::SETNAME##Colour(QColor value) \
 { \
     mThemeColours.GETNAME##Colour = value; \
     if (mUseThemeColours) \
@@ -151,7 +152,7 @@ void LxQtSysStatContent::SETNAME##Colour(QColor value) \
 #undef QSS_NET_COLOUR
 #define QSS_NET_COLOUR(GETNAME, SETNAME) \
 QSS_GET_COLOUR(GETNAME) \
-void LxQtSysStatContent::SETNAME##Colour(QColor value) \
+void LXQtSysStatContent::SETNAME##Colour(QColor value) \
 { \
     mThemeColours.GETNAME##Colour = value; \
     if (mUseThemeColours) \
@@ -180,7 +181,7 @@ QSS_NET_COLOUR(netTransmitted, setNetTransmitted)
 #undef QSS_COLOUR
 #undef QSS_GET_COLOUR
 
-void LxQtSysStatContent::mixNetColours()
+void LXQtSysStatContent::mixNetColours()
 {
     QColor netReceivedColour_hsv = mColours.netReceivedColour.toHsv();
     QColor netTransmittedColour_hsv = mColours.netTransmittedColour.toHsv();
@@ -193,7 +194,7 @@ void LxQtSysStatContent::mixNetColours()
         (netReceivedColour_hsv.valueF()      + netTransmittedColour_hsv.valueF()     ) / 2 );
 }
 
-void LxQtSysStatContent::setTitleFont(QFont value)
+void LXQtSysStatContent::setTitleFont(QFont value)
 {
     mTitleFont = value;
     updateTitleFontPixelHeight();
@@ -201,7 +202,7 @@ void LxQtSysStatContent::setTitleFont(QFont value)
     update();
 }
 
-void LxQtSysStatContent::updateTitleFontPixelHeight()
+void LXQtSysStatContent::updateTitleFontPixelHeight()
 {
     if (mTitleLabel.isEmpty())
         mTitleFontPixelHeight = 0;
@@ -212,7 +213,7 @@ void LxQtSysStatContent::updateTitleFontPixelHeight()
     }
 }
 
-void LxQtSysStatContent::updateSettings(const QSettings *settings)
+void LXQtSysStatContent::updateSettings(const PluginSettings *settings)
 {
     double old_updateInterval = mUpdateInterval;
     int old_minimalSize = mMinimalSize;
@@ -231,7 +232,7 @@ void LxQtSysStatContent::updateSettings(const QSettings *settings)
     mTitleLabel = settings->value("title/label", QString()).toString();
 
     // default to CPU monitoring
-    mDataType = settings->value("data/type", QString("CPU")).toString();
+    mDataType = settings->value("data/type", LXQtSysStatConfiguration::msStatTypes[0]).toString();
 
     mDataSource = settings->value("data/source", QString("cpu")).toString();
 
@@ -300,7 +301,10 @@ void LxQtSysStatContent::updateSettings(const QSettings *settings)
     if (dataTypeChanged)
     {
         if (mStat)
+        {
             mStat->deleteLater();
+            mStat = nullptr;
+        }
 
         if (mDataType == "CPU")
             mStat = new SysStat::CpuStat(this);
@@ -352,12 +356,12 @@ void LxQtSysStatContent::updateSettings(const QSettings *settings)
         update();
 }
 
-void LxQtSysStatContent::resizeEvent(QResizeEvent * /*event*/)
+void LXQtSysStatContent::resizeEvent(QResizeEvent * /*event*/)
 {
     reset();
 }
 
-void LxQtSysStatContent::reset()
+void LXQtSysStatContent::reset()
 {
     setMinimumSize(mPlugin->panel()->isHorizontal() ? mMinimalSize : 2,
                    mPlugin->panel()->isHorizontal() ? 2 : mMinimalSize);
@@ -375,20 +379,29 @@ T clamp(const T &value, const T &min, const T &max)
 }
 
 // QPainter.drawLine with pen set to Qt::transparent doesn't clear anything
-void LxQtSysStatContent::clearLine()
+void LXQtSysStatContent::clearLine()
 {
     QRgb bg = QColor(Qt::transparent).rgba();
     for (int i = 0; i < 100; ++i)
         reinterpret_cast<QRgb*>(mHistoryImage.scanLine(i))[mHistoryOffset] = bg;
 }
 
-void LxQtSysStatContent::cpuUpdate(float user, float nice, float system, float other, float frequencyRate, uint)
+void LXQtSysStatContent::cpuUpdate(float user, float nice, float system, float other, float frequencyRate, uint)
 {
-    int y_system = clamp(static_cast<int>(system * 100.0 * frequencyRate)           , 0, 99);
-    int y_user   = clamp(static_cast<int>(user   * 100.0 * frequencyRate) + y_system, 0, 99);
-    int y_nice   = clamp(static_cast<int>(nice   * 100.0 * frequencyRate) + y_user  , 0, 99);
-    int y_other  = clamp(static_cast<int>(other  * 100.0 * frequencyRate) + y_nice  , 0, 99);
-    int y_freq   = clamp(static_cast<int>(         100.0 * frequencyRate)           , 0, 99);
+    int y_system = static_cast<int>(system * 100.0 * frequencyRate);
+    int y_user   = static_cast<int>(user   * 100.0 * frequencyRate);
+    int y_nice   = static_cast<int>(nice   * 100.0 * frequencyRate);
+    int y_other  = static_cast<int>(other  * 100.0 * frequencyRate);
+    int y_freq   = static_cast<int>(         100.0 * frequencyRate);
+
+    toolTipInfo(tr("system: %1%<br>user: %2%<br>nice: %3%<br>other: %4%<br>freq: %5%", "CPU tooltip information")
+            .arg(y_system).arg(y_user).arg(y_nice).arg(y_other).arg(y_freq));
+
+    y_system = clamp(y_system, 0, 99);
+    y_user   = clamp(y_user + y_system, 0, 99);
+    y_nice   = clamp(y_nice + y_user  , 0, 99);
+    y_other  = clamp(y_other, 0, 99);
+    y_freq   = clamp(y_freq, 0, 99);
 
     clearLine();
     QPainter painter(&mHistoryImage);
@@ -423,12 +436,20 @@ void LxQtSysStatContent::cpuUpdate(float user, float nice, float system, float o
     update(0, mTitleFontPixelHeight, width(), height() - mTitleFontPixelHeight);
 }
 
-void LxQtSysStatContent::cpuUpdate(float user, float nice, float system, float other)
+void LXQtSysStatContent::cpuUpdate(float user, float nice, float system, float other)
 {
-    int y_system = clamp(static_cast<int>(system * 100.0)           , 0, 99);
-    int y_user   = clamp(static_cast<int>(user   * 100.0) + y_system, 0, 99);
-    int y_nice   = clamp(static_cast<int>(nice   * 100.0) + y_user  , 0, 99);
-    int y_other  = clamp(static_cast<int>(other  * 100.0) + y_nice  , 0, 99);
+    int y_system = static_cast<int>(system * 100.0);
+    int y_user   = static_cast<int>(user   * 100.0);
+    int y_nice   = static_cast<int>(nice   * 100.0);
+    int y_other  = static_cast<int>(other  * 100.0);
+
+    toolTipInfo(tr("system: %1%<br>user: %2%<br>nice: %3%<br>other: %4%<br>freq: n/a", "CPU tooltip information")
+            .arg(y_system).arg(y_user).arg(y_nice).arg(y_other));
+
+    y_system = clamp(y_system, 0, 99);
+    y_user   = clamp(y_user + y_system, 0, 99);
+    y_nice   = clamp(y_nice + y_user, 0, 99);
+    y_other  = clamp(y_other + y_nice, 0, 99);
 
     clearLine();
     QPainter painter(&mHistoryImage);
@@ -458,11 +479,18 @@ void LxQtSysStatContent::cpuUpdate(float user, float nice, float system, float o
     update(0, mTitleFontPixelHeight, width(), height() - mTitleFontPixelHeight);
 }
 
-void LxQtSysStatContent::memoryUpdate(float apps, float buffers, float cached)
+void LXQtSysStatContent::memoryUpdate(float apps, float buffers, float cached)
 {
-    int y_apps    = clamp(static_cast<int>(apps    * 100.0)            , 0, 99);
-    int y_buffers = clamp(static_cast<int>(buffers * 100.0) + y_apps   , 0, 99);
-    int y_cached  = clamp(static_cast<int>(cached  * 100.0) + y_buffers, 0, 99);
+    int y_apps    = static_cast<int>(apps    * 100.0);
+    int y_buffers = static_cast<int>(buffers * 100.0);
+    int y_cached  = static_cast<int>(cached  * 100.0);
+
+    toolTipInfo(tr("apps: %1%<br>buffers: %2%<br>cached: %3%", "Memory tooltip information")
+        .arg(y_apps).arg(y_buffers).arg(y_cached));
+
+    y_apps    = clamp(y_apps, 0, 99);
+    y_buffers = clamp(y_buffers + y_apps, 0, 99);
+    y_cached  = clamp(y_cached + y_buffers, 0, 99);
 
     clearLine();
     QPainter painter(&mHistoryImage);
@@ -487,9 +515,13 @@ void LxQtSysStatContent::memoryUpdate(float apps, float buffers, float cached)
     update(0, mTitleFontPixelHeight, width(), height() - mTitleFontPixelHeight);
 }
 
-void LxQtSysStatContent::swapUpdate(float used)
+void LXQtSysStatContent::swapUpdate(float used)
 {
-    int y_used = clamp(static_cast<int>(used * 100.0), 0, 99);
+    int y_used = static_cast<int>(used * 100.0);
+
+    toolTipInfo(tr("used: %1%", "Swap tooltip information").arg(y_used));
+
+    y_used = clamp(y_used, 0, 99);
 
     clearLine();
     QPainter painter(&mHistoryImage);
@@ -504,7 +536,7 @@ void LxQtSysStatContent::swapUpdate(float used)
     update(0, mTitleFontPixelHeight, width(), height() - mTitleFontPixelHeight);
 }
 
-void LxQtSysStatContent::networkUpdate(unsigned received, unsigned transmitted)
+void LXQtSysStatContent::networkUpdate(unsigned received, unsigned transmitted)
 {
     qreal min_value = qMin(qMax(static_cast<qreal>(qMin(received, transmitted)) / mNetRealMaximumSpeed, static_cast<qreal>(0.0)), static_cast<qreal>(1.0));
     qreal max_value = qMin(qMax(static_cast<qreal>(qMax(received, transmitted)) / mNetRealMaximumSpeed, static_cast<qreal>(0.0)), static_cast<qreal>(1.0));
@@ -514,8 +546,13 @@ void LxQtSysStatContent::networkUpdate(unsigned received, unsigned transmitted)
         max_value = qLn(max_value * (mLogScaleMax - 1.0) + 1.0) / qLn(2.0) / static_cast<qreal>(mLogScaleSteps);
     }
 
-    int y_min_value = clamp(static_cast<int>(min_value * 100.0)              , 0, 99);
-    int y_max_value = clamp(static_cast<int>(max_value * 100.0) + y_min_value, 0, 99);
+    int y_min_value = static_cast<int>(min_value * 100.0);
+    int y_max_value = static_cast<int>(max_value * 100.0);
+
+    toolTipInfo(tr("min: %1%<br>max: %2%", "Network tooltip information").arg(y_min_value).arg(y_max_value));
+
+    y_min_value = clamp(y_min_value, 0, 99);
+    y_max_value = clamp(y_max_value + y_min_value, 0, 99);
 
     clearLine();
     QPainter painter(&mHistoryImage);
@@ -535,7 +572,7 @@ void LxQtSysStatContent::networkUpdate(unsigned received, unsigned transmitted)
     update(0, mTitleFontPixelHeight, width(), height() - mTitleFontPixelHeight);
 }
 
-void LxQtSysStatContent::paintEvent(QPaintEvent *event)
+void LXQtSysStatContent::paintEvent(QPaintEvent *event)
 {
     QPainter p(this);
 
@@ -580,3 +617,11 @@ void LxQtSysStatContent::paintEvent(QPaintEvent *event)
         p.drawLine(QPointF(0.0, y), QPointF(w, y));
     }
 }
+
+void LXQtSysStatContent::toolTipInfo(QString const & tooltip)
+{
+    setToolTip(QString("<b>%1(%2)</b><br>%3")
+            .arg(QCoreApplication::translate("LXQtSysStatConfiguration", mDataType.toStdString().c_str()))
+            .arg(QCoreApplication::translate("LXQtSysStatConfiguration", mDataSource.toStdString().c_str()))
+            .arg(tooltip));
+}
