@@ -1,9 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
- * http://lxqt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2011 Razor team
  *            2014 LXQt team
@@ -58,6 +57,8 @@ LXQtTaskBar::LXQtTaskBar(ILXQtPanelPlugin *plugin, QWidget *parent) :
     QFrame(parent),
     mSignalMapper(new QSignalMapper(this)),
     mButtonStyle(Qt::ToolButtonTextBesideIcon),
+    mButtonWidth(400),
+    mButtonHeight(100),
     mCloseOnMiddleClick(true),
     mRaiseOnCurrentDesktop(true),
     mShowOnlyOneDesktopTasks(false),
@@ -65,6 +66,7 @@ LXQtTaskBar::LXQtTaskBar(ILXQtPanelPlugin *plugin, QWidget *parent) :
     mShowOnlyCurrentScreenTasks(false),
     mShowOnlyMinimizedTasks(false),
     mAutoRotate(true),
+    mGroupingEnabled(true),
     mShowGroupOnHover(true),
     mIconByClass(false),
     mCycleOnWheelScroll(true),
@@ -90,7 +92,6 @@ LXQtTaskBar::LXQtTaskBar(ILXQtPanelPlugin *plugin, QWidget *parent) :
     connect(mSignalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &LXQtTaskBar::activateTask);
     QTimer::singleShot(0, this, &LXQtTaskBar::registerShortcuts);
 
-    connect(KWindowSystem::self(), SIGNAL(stackingOrderChanged()), SLOT(refreshTaskList()));
     connect(KWindowSystem::self(), static_cast<void (KWindowSystem::*)(WId, NET::Properties, NET::Properties2)>(&KWindowSystem::windowChanged)
             , this, &LXQtTaskBar::onWindowChanged);
     connect(KWindowSystem::self(), &KWindowSystem::windowAdded, this, &LXQtTaskBar::onWindowAdded);
@@ -331,7 +332,8 @@ void LXQtTaskBar::refreshTaskList()
 {
     QList<WId> new_list;
     // Just add new windows to groups, deleting is up to the groups
-    for (auto const wnd: KWindowSystem::stackingOrder())
+    const auto wnds = KWindowSystem::stackingOrder();
+    for (auto const wnd: wnds)
     {
         if (acceptWindow(wnd))
         {
@@ -360,7 +362,12 @@ void LXQtTaskBar::onWindowChanged(WId window, NET::Properties prop, NET::Propert
 {
     auto i = mKnownWindows.find(window);
     if (mKnownWindows.end() != i)
-        (*i)->onWindowChanged(window, prop, prop2);
+    {
+        if (!(*i)->onWindowChanged(window, prop, prop2) && acceptWindow(window))
+        { // window is removed from a group because of class change, so we should add it again
+            addWindow(window);
+        }
+    }
 }
 
 void LXQtTaskBar::onWindowAdded(WId window)
