@@ -1,9 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
- * http://lxqt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2011 Razor team
  *            2014 LXQt team
@@ -461,6 +460,42 @@ void LXQtTaskButton::moveApplicationToDesktop()
     KWindowSystem::setOnDesktop(mWindow, desk);
 }
 
+/************************************************
+
+ ************************************************/
+void LXQtTaskButton::moveApplication()
+{
+    KWindowInfo info(mWindow, NET::WMDesktop);
+    if (!info.isOnCurrentDesktop())
+        KWindowSystem::setCurrentDesktop(info.desktop());
+    if (isMinimized())
+        KWindowSystem::unminimizeWindow(mWindow);
+    KWindowSystem::forceActiveWindow(mWindow);
+    const QRect& g = KWindowInfo(mWindow, NET::WMGeometry).geometry();
+    int X = g.center().x();
+    int Y = g.center().y();
+    QCursor::setPos(X, Y);
+    NETRootInfo(QX11Info::connection(), NET::WMMoveResize).moveResizeRequest(mWindow, X, Y, NET::Move);
+}
+
+/************************************************
+
+ ************************************************/
+void LXQtTaskButton::resizeApplication()
+{
+    KWindowInfo info(mWindow, NET::WMDesktop);
+    if (!info.isOnCurrentDesktop())
+        KWindowSystem::setCurrentDesktop(info.desktop());
+    if (isMinimized())
+        KWindowSystem::unminimizeWindow(mWindow);
+    KWindowSystem::forceActiveWindow(mWindow);
+    const QRect& g = KWindowInfo(mWindow, NET::WMGeometry).geometry();
+    int X = g.bottomRight().x();
+    int Y = g.bottomRight().y();
+    QCursor::setPos(X, Y);
+    NETRootInfo(QX11Info::connection(), NET::WMMoveResize).moveResizeRequest(mWindow, X, Y, NET::BottomRight);
+}
+
 /************************************************
 
  ************************************************/
@@ -532,6 +567,15 @@ void LXQtTaskButton::contextMenuEvent(QContextMenuEvent* event)
         connect(a, SIGNAL(triggered(bool)), this, SLOT(moveApplicationToDesktop()));
     }
 
+    /********** Move/Resize **********/
+    menu->addSeparator();
+    a = menu->addAction(tr("&Move"));
+    a->setEnabled(info.actionSupported(NET::ActionMove) && !(state & NET::Max) && !(state & NET::FullScreen));
+    connect(a, &QAction::triggered, this, &LXQtTaskButton::moveApplication);
+    a = menu->addAction(tr("Resi&ze"));
+    a->setEnabled(info.actionSupported(NET::ActionResize) && !(state & NET::Max) && !(state & NET::FullScreen));
+    connect(a, &QAction::triggered, this, &LXQtTaskButton::resizeApplication);
+
     /********** State menu **********/
     menu->addSeparator();
 
