@@ -2,103 +2,126 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="th_TH">
 <context>
-    <name>LxQtTaskButton</name>
+    <name>LXQtTaskBar</name>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="367"/>
+        <location filename="../lxqttaskbar.cpp" line="648"/>
+        <source>Activate task %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LXQtTaskButton</name>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="513"/>
         <source>Application</source>
         <translation>โปรแกรม</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="400"/>
+        <location filename="../lxqttaskbutton.cpp" line="547"/>
         <source>To &amp;Desktop</source>
         <translation>ไปยัง &amp;พ&amp;ื&amp;้นโต๊ะ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="402"/>
+        <location filename="../lxqttaskbutton.cpp" line="549"/>
         <source>&amp;All Desktops</source>
         <translation>&amp;ท&amp;ุกพื้นโต๊ะ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="410"/>
+        <location filename="../lxqttaskbutton.cpp" line="557"/>
         <source>Desktop &amp;%1</source>
         <translation>พื้นโต๊ะ &amp;%1</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="417"/>
+        <location filename="../lxqttaskbutton.cpp" line="564"/>
         <source>&amp;To Current Desktop</source>
         <translation>&amp;ไปยังพื้นโต๊ะปัจจุบัน</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="426"/>
+        <location filename="../lxqttaskbutton.cpp" line="572"/>
+        <source>&amp;Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="575"/>
+        <source>Resi&amp;ze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="582"/>
         <source>Ma&amp;ximize</source>
         <translation>&amp;ขยายแผ่</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="433"/>
+        <location filename="../lxqttaskbutton.cpp" line="589"/>
         <source>Maximize vertically</source>
         <translation>ขยายแผ่ทางแนวตั้ง</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="438"/>
+        <location filename="../lxqttaskbutton.cpp" line="594"/>
         <source>Maximize horizontally</source>
         <translation>ขยายแผ่ทางแนวนอน</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="444"/>
+        <location filename="../lxqttaskbutton.cpp" line="600"/>
         <source>&amp;Restore</source>
         <translation>&amp;ค&amp;ืนสภาพ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="448"/>
+        <location filename="../lxqttaskbutton.cpp" line="604"/>
         <source>Mi&amp;nimize</source>
         <translation>&amp;ย&amp;่อเก็บ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="454"/>
+        <location filename="../lxqttaskbutton.cpp" line="610"/>
         <source>Roll down</source>
         <translation>ม้วนลง</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="460"/>
+        <location filename="../lxqttaskbutton.cpp" line="616"/>
         <source>Roll up</source>
         <translation>ม้วนขึ้น</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="468"/>
+        <location filename="../lxqttaskbutton.cpp" line="624"/>
         <source>&amp;Layer</source>
         <translation>&amp;ลำดับชั้น</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="470"/>
+        <location filename="../lxqttaskbutton.cpp" line="626"/>
         <source>Always on &amp;top</source>
         <translation>ด้าน&amp;หน้าเสมอ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="476"/>
+        <location filename="../lxqttaskbutton.cpp" line="632"/>
         <source>&amp;Normal</source>
         <translation>&amp;ปกติ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="482"/>
+        <location filename="../lxqttaskbutton.cpp" line="638"/>
         <source>Always on &amp;bottom</source>
         <translation>ด้านหลัง&amp;งเสมอ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="490"/>
+        <location filename="../lxqttaskbutton.cpp" line="646"/>
         <source>&amp;Close</source>
         <translation>ปิ&amp;ด</translation>
     </message>
 </context>
 <context>
-    <name>LxQtTaskbarConfiguration</name>
+    <name>LXQtTaskGroup</name>
     <message>
-        <source>LxQt Task Manager Settings</source>
-        <translation type="vanished">ค่าตั้งตัวจัดการงาน LxQt</translation>
+        <location filename="../lxqttaskgroup.cpp" line="82"/>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Window List Content</source>
-        <translation type="vanished">การแสดงรายการหน้าต่าง</translation>
+        <location filename="../lxqttaskgroup.cpp" line="84"/>
+        <source>Close group</source>
+        <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>LXQtTaskbarConfiguration</name>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
         <source>Task Manager Settings</source>
@@ -106,66 +129,104 @@
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
-        <source>Taskbar Contents</source>
+        <source>General</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="26"/>
-        <source>Show windows from current desktop</source>
-        <translation>แสดงหน้าต่างเฉพาะพื้นโต๊ะปัจจุบัน</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="36"/>
-        <source>Show windows from all desktops</source>
-        <translation>แสดงหน้าต่างจากทุกพื้นโต๊ะ</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="49"/>
-        <source>Taskbar Appearance</source>
+        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
+        <source>Show only windows from desktop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="65"/>
-        <source>Minimum button width</source>
+        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
+        <source>Show only windows from &amp;panel&apos;s screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="88"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
+        <source>Show only minimized windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
+        <source>Raise minimized windows on current desktop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="83"/>
+        <source>Cycle windows on wheel scrolling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="93"/>
+        <source>Window &amp;grouping</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="102"/>
+        <source>Show popup on mouse hover</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
+        <source>Appearance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="131"/>
+        <source>Maximum button width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="144"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="170"/>
+        <source> px</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="157"/>
+        <source>Maximum button height</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="190"/>
+        <source>Use icons by WindowClass, if available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="183"/>
         <source>Auto&amp;rotate buttons when the panel is vertical</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Window List Appearance</source>
-        <translation type="vanished">ลักษณะรายการหน้าต่าง</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="121"/>
         <source>Button style</source>
         <translation>รูปแบบปุ่ม</translation>
     </message>
     <message>
-        <source>Max button width</source>
-        <translation type="vanished">ความกว้างปุ่มขนาดสูงสุด</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="98"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
         <source>Close on middle-click</source>
         <translation>ปิดด้วยการคลิกปุ่มกลาง</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
         <source>Icon and text</source>
         <translation>ไอคอนและข้อความ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
         <source>Only icon</source>
         <translation>ไอคอนเท่านั้น</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
         <source>Only text</source>
         <translation>ข้อความเท่านั้น</translation>
     </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
+        <source>Current</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
